==> glog-3.00.tar.gz: glog-3.00/addcomment.php <==
<?php
# Add new comment to blog entry
#
# $Id: addcomment.php,v 1.10 2005/06/29 15:01:59 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("config.php");
	include(LIB_DIR . "funcs.php");

	/* Process the data */
	$data = array();
	$data["author"]		= "";
	$data["email"]		= "";
	$data["url"]		= "";
	$data["comment"]	= "";
	$data["savedata"]	= 0;

	$data["ip"]			= $_SERVER["REMOTE_ADDR"];
	$data["proxy"]		= "";
	$data["ua"]			= "";

	if (isset($_SERVER["HTTP_X_FORWARDED_FOR"]))
		$data["proxy"] = trim(ltrim(ereg_replace("[\t]"," ",$_SERVER["HTTP_X_FORWARDED_FOR"])));

	if (isset($_SERVER["HTTP_USER_AGENT"]))
		$data["ua"] = trim(ltrim(ereg_replace("[\t]"," ",$_SERVER["HTTP_USER_AGENT"])));

	if (isset($_COOKIE["DIARYDATA"])) {
		@list($data["savedata"],$data["author"],$data["email"],$data["url"]) = split(";", $_COOKIE["DIARYDATA"]);
		$data["author"]		= trim(ltrim($data["author"]));
		$data["email"]		= trim(ltrim(ereg_replace("[^-_@.A-Za-z0-9]","",$data["email"])));
		$data["url"]		= urldecode(trim(ltrim($data["url"])));
		$data["url"]		= ereg_replace("[^-~=:.?/&_ A-Za-z0-9]","",$data["url"]);
		$data["savedata"]	= (int)ereg_replace("[^0-9]","",$data["savedata"]);
	}

	@$data["ok"]		= $_POST["ok"];
	if ($data["ok"]) {
		@$data["author"]	= trim(ltrim($_POST["author"]));
		@$data["email"]		= trim(ltrim(ereg_replace("[^-_@.A-Za-z0-9]","",$_POST["email"])));
		@$data["url"]		= urldecode(trim(ltrim($_POST["url"])));
		@$data["url"]		= ereg_replace("[^-~=:.?/&_ A-Za-z0-9]","",$data["url"]);
		@$data["comment"]	= trim(ltrim(ereg_replace("\t"," ",$_POST["comment"])));
		@$data["savedata"]	= (int)ereg_replace("[^0-9]","",$_POST["savedata"]);
	}

	@$data["preview"]	= strlen($_POST["preview"]) > 0;
	@$data["cancel"]	= strlen($_POST["cancel"]) > 0;
	@$data["post"]		= strlen($_POST["post"]) > 0;

	/* Error handling */
	$form_err["author"]  = false;
	$form_err["comment"] = false;
	$form_ok = false;
	if ($data["ok"]) {
		@$form_err["author"]  = strlen($_POST["author"]) == 0;
		@$form_err["comment"] = strlen($_POST["comment"]) == 0;
		$form_ok = !$form_err["author"] && !$form_err["comment"];
	}

	/* On "cancel" go to archive page and exit */
	if ($data["cancel"]) {
		header("Location: " . BASEDIR . "archive.php/{$date}#top");
		exit;
	}

	if ($form_ok && $data["post"]) {
		if ($data["savedata"]) {
			setcookie("DIARYDATA","{$data['savedata']};{$data['author']};{$data['email']};{$data['url']}",time()+86400*60,"/");
		} else {
			setcookie("DIARYDATA","",0,"/");
		}
		$tmp_comment = ereg_replace("\r","",$data["comment"]);
		$tmp_comment = ereg_replace('\n',' n',$tmp_comment);

		/* $published, $ip, $proxy, $ua, $author, $email, $url, $text */
		$new_comment  = time() . "\t";
		$new_comment .= $data["ip"] . "\t";
		$new_comment .= $data["proxy"] . "\t";
		$new_comment .= $data["ua"] . "\t";
		$new_comment .= ereg_replace("[\t\n]"," ",$data["author"]) . "\t";
		$new_comment .= ereg_replace("[\t\n]"," ",$data["email"]) . "\t";
		$new_comment .= ereg_replace("[\t\n]"," ",$data["url"]) . "\t";
		$new_comment .= ereg_replace("\n",'\n',$tmp_comment) . "\n";

		$approve_file = "";
		$dir_writable = false;
		$approve_comments = APPROVE_COMMENTS;

		/* Handle IP white list */
		if (!IGNORE_WHITELIST &&
		    file_exists(IP_WHITELIST_FILE) && is_readable(IP_WHITELIST_FILE))
		{
			$white_list = file(IP_WHITELIST_FILE);
			if (is_array($white_list)) {
				foreach($white_list as $tid => $ip) {
					$ip = trim(ltrim($ip));
					if (strlen($ip) && !ereg("^#",$ip) &&
					    ereg("^$ip",$data["ip"]))
					{
						$approve_comments = false;
						$data['proxy'] .= "Whitelisted IP: $ip";
					}
				}
			}
		}
		/* Handle IP black list */
		if (file_exists(IP_BLACKLIST_FILE) && is_readable(IP_BLACKLIST_FILE)) {
			$black_list = file(IP_BLACKLIST_FILE);
			if (is_array($black_list)) {
				foreach($black_list as $id => $ip) {
					$ip = trim(ltrim($ip));
					if (strlen($ip) && !ereg("^#",$ip) &&
					    ereg("^$ip",$data["ip"]))
					{
						$approve_comments = true;
						$data['proxy'] .= "Blacklisted: $ip";
					}
				}
			}
		}
		/* Handle old posts */
		if (APPROVE_AFTER) {
			$now = time();
			$post = strtotime($date);
			if (floor(($now - $post) / 86400) > APPROVE_AFTER)
				$approve_comments = true;
		}
		/* Approve comments without cyrillic chars */
		if (!ereg("[--]",$data["comment"]))
			$approve_comments = true;

		if ($approve_comments) {
			/* Use temporary file */
			$approve_file = time() . "_" . gen_uniq();
			$comment_file = COMMENT_APPROVE_DIR . $date . "_" . $approve_file;
			$dir_writable = is_writable(COMMENT_APPROVE_DIR);
		} else {
			/* Save the comment directly */
			$comment_file = COMMENT_DIR . $date . ".comments.txt";
			$dir_writable = is_writable(COMMENT_DIR);
		}
		if ($dir_writable) {
			/* Write file */
			ignore_user_abort(true);
			$umask = umask();
			umask(0111);
			if ($fh = fopen($comment_file,"a")) {
				if (flock($fh, LOCK_EX)) {
					fwrite($fh, $new_comment);
					fflush($fh);
					flock($fh, LOCK_UN);
				}
				fclose($fh);
			}
			umask($umask);
			ignore_user_abort(false);
		}

		/* Send email */
		$headers = "From: " . EMAIL_FROMNAME . " <" . EMAIL_FROM. ">\n";
		$headers .= "Return-path: " . EMAIL_FROM . "\n";
		$headers .= "Content-type: text/plain; charset=windows-1251\n";

		$body  = "IP     : " . $data["ip"] . " ({$data['proxy']})\n";
		$body .= "UA     : " . $data["ua"] . "\n\n";

		$body .= "  : " . $data["author"] . "\n";
		$body .= "Email  : " . $data["email"] . "\n";
		$body .= "URL    : " . $data["url"] . "\n";
		$body .= "  : " . "http://{$_SERVER['HTTP_HOST']}" . BASEDIR . "archive.php/{$date}" . "\n";
		if ($approve_comments) {
			$body .= "\nApprove:\n  http://{$_SERVER['HTTP_HOST']}" . BASEDIR . "appcomment.php/{$date}?cmt={$approve_file}" . "\n";
			$body .= "\nDelete :\n  http://{$_SERVER['HTTP_HOST']}" . BASEDIR . "appcomment.php/{$date}?cmt={$approve_file}&del=1" . "\n";
			$body .= "\n";
		}
		$body .= str_repeat("-", 72)."\n";
		$body .= wordwrap($data["comment"], 72) . "\n";
		$body .= str_repeat("-", 72)."\n";
		$body = ereg_replace("\r","",$body);

		$subject = "New comment for ${date}";
		if ($approve_comments) {
			$subject .= " [for approval]";
		}

		mail(EMAIL_TO, $subject, $body, $headers);
		if ($approve_comments) {
			header("Location: " . BASEDIR . "archive.php/{$date}?msg=appcmt#top");
		} else {
			header("Location: " . BASEDIR . "archive.php/{$date}?msg=addcmt#lastcomment");
		}
		exit;
	}

	html_begin("   / " . get_title($date));

	$days = load_days();

	print "<h4>  </h4>\n";
	if (isset($days[$date])) {
		$text = implode('', file(get_filename($date)));
		print_day($date, $text);
	} else {
		print "<h5>No entry for this day ($date)</h5><br />\n";
		html_end();
		exit;
	}
?>
<a name="add"></a>

<?
	/* Preview comment */
	if ($form_ok) { ?>
<blockquote id="cmt<?=$date?>">
<h5> </h5>
<?
		show_comment($data["comment"],$data["author"],$data["email"],$data["url"], time());
?>
<form method="post" action="<?=$_SERVER["PHP_SELF"]?>#add" name="previewform">
<input type="hidden" name="ok" value="1" />
<input type="hidden" name="author" value="<?=htmlspecialchars($data["author"])?>" />
<input type="hidden" name="email" value="<?=htmlspecialchars($data["email"])?>" />
<input type="hidden" name="url" value="<?=htmlspecialchars($data["url"])?>" />
<input type="hidden" name="comment" value="<?=htmlspecialchars($data["comment"])?>" />
<input type="hidden" name="savedata" value="<?=htmlspecialchars($data["savedata"])?>" />
<input type="submit" name="post" value="   " style="font-weight:bold" />
</form>
</blockquote>
<?	} ?>

<blockquote id="cmt<?=$date?>">
<h5>  </h5>

<form method="post" action="<?=$_SERVER["PHP_SELF"]?>#add" name="cmtform">
<input type="hidden" name="ok" value="1" />

<table border="0" cellpadding="2" cellspacing="0">
<?	if ($form_err["author"]) { ?>
<tr>
	<td valign="top"><br /></td>
	<td><b><i> </i></b></td>
</tr>
<?	} ?>
<tr>
	<td valign="top"><label for="author"> *</label></td>
	<td><input type="text" name="author" value="<?=htmlspecialchars($data["author"])?>" /> <em>  nicknames,        !</td>
</tr>
<tr>
	<td valign="top"><label for="email">mail</label></td>
	<td><input type="text" name="email" value="<?=htmlspecialchars($data["email"])?>" /> <em>user@example.com</td>
</tr>
<tr>
	<td valign="top"><label for="url">URL</label></td>
	<td><input type="text" name="url" value="<?=htmlspecialchars($data["url"])?>" /> <em>http://www.example.com/</td>
</tr>
<tr>
	<td valign="top"><br /></td>
	<td valign="top"><em>        .   .</td>
</tr>
<?	if ($form_err["comment"]) { ?>
<tr>
	<td valign="top"><br /></td>
	<td><b><i> </i></b></td>
</tr>
<?	} ?>
<tr>
	<td valign="top"><label for="comment"> *</label></td>
	<td valign="top"><textarea name="comment" rows="10" cols="50"><?=htmlspecialchars($data["comment"])?></textarea></td>
</tr>
<tr>
	<td><br /></td>
	<td><input type="checkbox" value="1" name="savedata" <?=$data["savedata"]==1?" checked":""?>/>     ,       </td>
</tr>
<tr>
	<td><br /></td>
	<td>
<input type="submit" name="cancel" value="  " />
<input type="submit" name="preview" value="   "<?=!$form_ok?' style="font-weight:bold"':''?> />
	</td>
</tr>
</table>

</form>

</blockquote>

<?	if ((!$data["ok"] && !strlen($data["author"])) || $form_err["author"]) { ?>
<script language="javascript" type="text/javascript">
<!--
	document.cmtform.author.focus();
// -->
</script>
<?	} ?>

<?	if (($form_err["comment"] || strlen($data["author"])) && !$form_err["author"]) { ?>
<script language="javascript" type="text/javascript">
<!--
	document.cmtform.comment.focus();
// -->
</script>
<?	} ?>

<?
	html_end();
?>

==> glog-3.50.tar.gz: glog-3.50/addcomment.php <==
<?php
# Add new comment to blog entry
#
# $Id: addcomment.php,v 1.11 2005/09/21 10:58:22 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	define('PROGRAM', 1);
	include("config.php");
	include(LIB_DIR . "funcs.php");

	/* Process the data */
	$data = array();
	$data["author"]		= "";
	$data["email"]		= "";
	$data["url"]		= "";
	$data["comment"]	= "";
	$data["savedata"]	= 0;

	$data["ip"]			= $_SERVER["REMOTE_ADDR"];
	$data["proxy"]		= "";
	$data["ua"]			= "";

	if (isset($_SERVER["HTTP_X_FORWARDED_FOR"]))
		$data["proxy"] = trim(ltrim(ereg_replace("[\t]"," ",$_SERVER["HTTP_X_FORWARDED_FOR"])));

	if (isset($_SERVER["HTTP_USER_AGENT"]))
		$data["ua"] = trim(ltrim(ereg_replace("[\t]"," ",$_SERVER["HTTP_USER_AGENT"])));

	if (isset($_COOKIE["DIARYDATA"])) {
		@list($data["savedata"],$data["author"],$data["email"],$data["url"]) = split(";", $_COOKIE["DIARYDATA"]);
		$data["author"]		= trim(ltrim($data["author"]));
		$data["email"]		= trim(ltrim(ereg_replace("[^-_@.A-Za-z0-9]","",$data["email"])));
		$data["url"]		= urldecode(trim(ltrim($data["url"])));
		$data["url"]		= ereg_replace("[^-~=:.?/&_ A-Za-z0-9]","",$data["url"]);
		$data["savedata"]	= (int)ereg_replace("[^0-9]","",$data["savedata"]);
	}

	@$data["ok"]		= $_POST["ok"];
	if ($data["ok"]) {
		@$data["author"]	= trim(ltrim($_POST["author"]));
		@$data["email"]		= trim(ltrim(ereg_replace("[^-_@.A-Za-z0-9]","",$_POST["email"])));
		@$data["url"]		= urldecode(trim(ltrim($_POST["url"])));
		@$data["url"]		= ereg_replace("[^-~=:.?/&_ A-Za-z0-9]","",$data["url"]);
		@$data["comment"]	= trim(ltrim(ereg_replace("\t"," ",$_POST["comment"])));
		@$data["savedata"]	= (int)ereg_replace("[^0-9]","",$_POST["savedata"]);
	}

	@$data["preview"]	= strlen($_POST["preview"]) > 0;
	@$data["cancel"]	= strlen($_POST["cancel"]) > 0;
	@$data["post"]		= strlen($_POST["post"]) > 0;

	/* Error handling */
	$form_err["author"]  = false;
	$form_err["comment"] = false;
	$form_ok = false;
	if ($data["ok"]) {
		@$form_err["author"]  = strlen($_POST["author"]) == 0;
		@$form_err["comment"] = strlen($_POST["comment"]) == 0;
		$form_ok = !$form_err["author"] && !$form_err["comment"];
	}

	/* On "cancel" go to archive page and exit */
	if ($data["cancel"]) {
		header("Location: " . BASEDIR . "archive.php/{$date}#top");
		exit;
	}

	if ($form_ok && $data["post"]) {
		if ($data["savedata"]) {
			setcookie("DIARYDATA","{$data['savedata']};{$data['author']};{$data['email']};{$data['url']}",time()+86400*60,"/");
		} else {
			setcookie("DIARYDATA","",0,"/");
		}
		$tmp_comment = ereg_replace("\r","",$data["comment"]);
		$tmp_comment = ereg_replace('\n',' n',$tmp_comment);

		/* $published, $ip, $proxy, $ua, $author, $email, $url, $text */
		$new_comment  = time() . "\t";
		$new_comment .= $data["ip"] . "\t";
		$new_comment .= $data["proxy"] . "\t";
		$new_comment .= $data["ua"] . "\t";
		$new_comment .= ereg_replace("[\t\n]"," ",$data["author"]) . "\t";
		$new_comment .= ereg_replace("[\t\n]"," ",$data["email"]) . "\t";
		$new_comment .= ereg_replace("[\t\n]"," ",$data["url"]) . "\t";
		$new_comment .= ereg_replace("\n",'\n',$tmp_comment) . "\n";

		$approve_file = "";
		$dir_writable = false;
		$approve_comments = APPROVE_COMMENTS;

		/* Handle IP white list */
		if (!IGNORE_WHITELIST &&
		    file_exists(IP_WHITELIST_FILE) && is_readable(IP_WHITELIST_FILE))
		{
			$white_list = file(IP_WHITELIST_FILE);
			if (is_array($white_list)) {
				foreach($white_list as $tid => $ip) {
					$ip = trim(ltrim($ip));
					if (strlen($ip) && !ereg("^#",$ip) &&
					    ereg("^$ip",$data["ip"]))
					{
						$approve_comments = false;
						$data['proxy'] .= "Whitelisted IP: $ip";
					}
				}
			}
		}
		/* Handle IP black list */
		if (file_exists(IP_BLACKLIST_FILE) && is_readable(IP_BLACKLIST_FILE)) {
			$black_list = file(IP_BLACKLIST_FILE);
			if (is_array($black_list)) {
				foreach($black_list as $id => $ip) {
					$ip = trim(ltrim($ip));
					if (strlen($ip) && !ereg("^#",$ip) &&
					    ereg("^$ip",$data["ip"]))
					{
						$approve_comments = true;
						$data['proxy'] .= "Blacklisted: $ip";
					}
				}
			}
		}
		/* Handle old posts */
		if (APPROVE_AFTER) {
			$now = time();
			$post = strtotime($date);
			if (floor(($now - $post) / 86400) > APPROVE_AFTER)
				$approve_comments = true;
		}
		/* Approve comments without cyrillic chars */
		if (!ereg("[--]",$data["comment"]))
			$approve_comments = true;

		if ($approve_comments) {
			/* Use temporary file */
			$approve_file = time() . "_" . gen_uniq();
			$comment_file = COMMENT_APPROVE_DIR . $date . "_" . $approve_file;
			$dir_writable = is_writable(COMMENT_APPROVE_DIR);
		} else {
			/* Save the comment directly */
			$comment_file = COMMENT_DIR . $date . ".comments.txt";
			$dir_writable = is_writable(COMMENT_DIR);
		}
		if ($dir_writable) {
			/* Write file */
			ignore_user_abort(true);
			$umask = umask();
			umask(0111);
			if ($fh = fopen($comment_file,"a")) {
				if (flock($fh, LOCK_EX)) {
					fwrite($fh, $new_comment);
					fflush($fh);
					flock($fh, LOCK_UN);
				}
				fclose($fh);
			}
			umask($umask);
			ignore_user_abort(false);
		}

		/* Send email */
		$headers = "From: " . EMAIL_FROMNAME . " <" . EMAIL_FROM. ">\n";
		$headers .= "Return-path: " . EMAIL_FROM . "\n";
		$headers .= "Content-type: text/plain; charset=windows-1251\n";

		$body  = "IP     : " . $data["ip"] . " ({$data['proxy']})\n";
		$body .= "UA     : " . $data["ua"] . "\n\n";

		$body .= "  : " . $data["author"] . "\n";
		$body .= "Email  : " . $data["email"] . "\n";
		$body .= "URL    : " . $data["url"] . "\n";
		$body .= "  : " . "http://{$_SERVER['HTTP_HOST']}" . BASEDIR . "archive.php/{$date}" . "\n";
		if ($approve_comments) {
			$body .= "\nApprove:\n  http://{$_SERVER['HTTP_HOST']}" . BASEDIR . "appcomment.php/{$date}?cmt={$approve_file}" . "\n";
			$body .= "\nDelete :\n  http://{$_SERVER['HTTP_HOST']}" . BASEDIR . "appcomment.php/{$date}?cmt={$approve_file}&del=1" . "\n";
			$body .= "\n";
		}
		$body .= str_repeat("-", 72)."\n";
		$body .= wordwrap($data["comment"], 72) . "\n";
		$body .= str_repeat("-", 72)."\n";
		$body = ereg_replace("\r","",$body);

		$subject = "New comment for ${date}";
		if ($approve_comments) {
			$subject .= " [for approval]";
		}

		mail(EMAIL_TO, $subject, $body, $headers);
		if ($approve_comments) {
			header("Location: " . BASEDIR . "archive.php/{$date}?msg=appcmt#top");
		} else {
			header("Location: " . BASEDIR . "archive.php/{$date}?msg=addcmt#lastcomment");
		}
		exit;
	}

	html_begin("   / " . get_title($date));

	$days = load_days();

	print "<h4>  </h4>\n";
	if (isset($days[$date])) {
		$text = implode('', file(get_filename($date)));
		print_day($date, $text);
	} else {
		print "<h5>No entry for this day ($date)</h5><br />\n";
		html_end();
		exit;
	}
?>
<a name="add"></a>

<?
	/* Preview comment */
	if ($form_ok) { ?>
<blockquote id="cmt<?=$date?>">
<h5> </h5>
<?
		show_comment($data["comment"],$data["author"],$data["email"],$data["url"], time());
?>
<form method="post" action="<?=$_SERVER["PHP_SELF"]?>#add" name="previewform">
<input type="hidden" name="ok" value="1" />
<input type="hidden" name="author" value="<?=htmlspecialchars($data["author"])?>" />
<input type="hidden" name="email" value="<?=htmlspecialchars($data["email"])?>" />
<input type="hidden" name="url" value="<?=htmlspecialchars($data["url"])?>" />
<input type="hidden" name="comment" value="<?=htmlspecialchars($data["comment"])?>" />
<input type="hidden" name="savedata" value="<?=htmlspecialchars($data["savedata"])?>" />
<input type="submit" name="post" value="   " style="font-weight:bold" />
</form>
</blockquote>
<?	} ?>

<blockquote id="cmt<?=$date?>form">
<h5>  </h5>

<form method="post" action="<?=$_SERVER["PHP_SELF"]?>#add" name="cmtform">
<input type="hidden" name="ok" value="1" />

<table border="0" cellpadding="2" cellspacing="0">
<?	if ($form_err["author"]) { ?>
<tr>
	<td valign="top"><br /></td>
	<td><b><i> </i></b></td>
</tr>
<?	} ?>
<tr>
	<td valign="top"><label for="author"> *</label></td>
	<td><input type="text" id="author" name="author" value="<?=htmlspecialchars($data["author"])?>" /> <em>  nicknames,        !</em></td>
</tr>
<tr>
	<td valign="top"><label for="email">mail</label></td>
	<td><input type="text" id="email" name="email" value="<?=htmlspecialchars($data["email"])?>" /> <em>user@example.com</em></td>
</tr>
<tr>
	<td valign="top"><label for="url">URL</label></td>
	<td><input type="text" id="url" name="url" value="<?=htmlspecialchars($data["url"])?>" /> <em>http://www.example.com/</em></td>
</tr>
<tr>
	<td valign="top"><br /></td>
	<td valign="top"><em>        .   .</em></td>
</tr>
<?	if ($form_err["comment"]) { ?>
<tr>
	<td valign="top"><br /></td>
	<td><b><i> </i></b></td>
</tr>
<?	} ?>
<tr>
	<td valign="top"><label for="comment"> *</label></td>
	<td valign="top"><textarea id="comment" name="comment" rows="10" cols="50"><?=htmlspecialchars($data["comment"])?></textarea></td>
</tr>
<tr>
	<td><br /></td>
	<td><input type="checkbox" value="1" name="savedata" <?=$data["savedata"]==1?" checked":""?>/>     ,       </td>
</tr>
<tr>
	<td><br /></td>
	<td>
<input type="submit" name="cancel" value="  " />
<input type="submit" name="preview" value="   "<?=!$form_ok?' style="font-weight:bold"':''?> />
	</td>
</tr>
</table>

</form>

</blockquote>

<?	if ((!$data["ok"] && !strlen($data["author"])) || $form_err["author"]) { ?>
<script language="javascript" type="text/javascript">
<!--
	document.cmtform.author.focus();
// -->
</script>
<?	} ?>

<?	if (($form_err["comment"] || strlen($data["author"])) && !$form_err["author"]) { ?>
<script language="javascript" type="text/javascript">
<!--
	document.cmtform.comment.focus();
// -->
</script>
<?	} ?>

<?
	html_end();
?>
